@@ -10,12 +10,11 @@
 Calculate the the correction of columns.
 """
 import copy
-import warnings
 from typing import List
 
 import numpy as np
 from sklearn.base import BaseEstimator, MetaEstimatorMixin
-from sklearn.datasets import load_boston
+
 from sklearn.feature_selection import SelectorMixin
 from sklearn.utils import check_random_state
 from sklearn.utils.validation import check_is_fitted
@@ -30,9 +29,11 @@ class Corr(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
 
     Examples
     ---------
-    >>> from sklearn.datasets import load_boston
+    >>> from sklearn.datasets import fetch_california_housing
     >>> from featurebox.selection import Corr
-    >>> x, y = load_boston(return_X_y=True)
+    >>> x, y = fetch_california_housing(return_X_y=True)
+    >>> x = x[:100]
+    >>> y = y[:100]
     >>> co = Corr(threshold=0.5)
     >>> nx = co.fit_transform(x)
 
@@ -41,9 +42,11 @@ class Corr(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
     Examples
     ---------
 
-    >>> from sklearn.datasets import load_boston
+    >>> from sklearn.datasets import fetch_california_housing
     >>> from featurebox.selection import Corr
-    >>> x, y = load_boston(return_X_y=True)
+    >>> x, y = fetch_california_housing(return_X_y=True)
+    >>> x = x[:100]
+    >>> y = y[:100]
     >>> co = Corr(threshold=0.7)
     >>> groups = co.count_cof(np.corrcoef(x[:,:7], rowvar=False))
     >>> groups[1]
@@ -57,9 +60,11 @@ class Corr(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
 
     Examples
     -----------
-    >>> from sklearn.datasets import load_boston
+    >>> from sklearn.datasets import fetch_california_housing
     >>> from featurebox.selection import Corr
-    >>> x, y = load_boston(return_X_y=True)
+    >>> x, y = fetch_california_housing(return_X_y=True)
+    >>> x = x[:100]
+    >>> y = y[:100]
     >>> co = Corr(threshold=0.7)
     >>> co.fit(x)
     Corr(threshold=0.7)
@@ -75,9 +80,11 @@ class Corr(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
 
     Examples
     -----------
-    >>> from sklearn.datasets import load_boston
+    >>> from sklearn.datasets import fetch_california_housing
     >>> from featurebox.selection import Corr
-    >>> x, y = load_boston(return_X_y=True)
+    >>> x, y = fetch_california_housing(return_X_y=True)
+    >>> x = x[:100]
+    >>> y = y[:100]
     >>> co = Corr(threshold=0.7,muti_index=[0,8],muti_grade=2)
     >>> # in range [0,8], the features are binding in to 2 sized: [[0,1],[2,3],[4,5],[6,7]]
     >>> co.fit(x)
@@ -132,10 +139,8 @@ class Corr(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
         # for nan
         self.nan_index_mark = ~np.array([np.all(np.isnan(cov[i])) for i in range(cov.shape[0])])
         if not np.all(self.nan_index_mark):
-            warnings.warn("There are some NAN values in correlation coefficient matrix, \n"
-                          "which could be constant features. \n"
-                          "and the features would removed later. \n"
-                          "See more in 'nan_index_mark' attribute", UserWarning)
+            print("There are some NAN values in correlation coefficient matrix, which could be constant features.\n"
+                  "The NAN features would removed later. See more in 'nan_index_mark' attribute.")
 
         cov = np.nan_to_num(cov)
         self.cov = cov
@@ -290,12 +295,15 @@ class Corr(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
             pass
 
 
-if __name__ == "__main__":
-    # x, y = load_boston(return_X_y=True)
-    # co = Corr(threshold=0.7)
-    # c = co.count_cof(np.corrcoef(x, rowvar=False))[1]
-
-    x, y = load_boston(return_X_y=True)
-    co = Corr(threshold=0.5, muti_index=[0, 8], muti_grade=2)
-
-    nx = co.fit_transform(x)
+# if __name__ == "__main__":
+#     # x, y = fetch_california_housing(return_X_y=True)
+#     # co = Corr(threshold=0.7)
+#     # c = co.count_cof(np.corrcoef(x, rowvar=False))[1]
+#     from sklearn.datasets import fetch_california_housing
+#
+#     x, y = fetch_california_housing(return_X_y=True)
+#     x = x[:100]
+#     y = y[:100]
+#     co = Corr(threshold=0.5, muti_index=[0, 8], muti_grade=2)
+#
+#     nx = co.fit_transform(x)
